@@ -41,8 +41,8 @@ class CalendarsQuerySet(BaseRefQuerySet):
 
 class CalendarsManager(BaseRefManager):
 
-    @staticmethod
-    def get_default():
+    @classmethod
+    def get_default(cls, ):
         try:
             return Calendars.objects.get(props=Calendars.props.default)
         except Calendars.DoesNotExist:
@@ -50,8 +50,8 @@ class CalendarsManager(BaseRefManager):
         except Calendars.MultipleObjectsReturned:
             raise Exception('Не однозначная установка текущего календаря.')
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
