@@ -519,8 +519,8 @@ class CommonQuerySet(QuerySet):
 
 
 class CommonManager(Manager):
-    @staticmethod
-    def delete_underscore_element(data):
+    @classmethod
+    def delete_underscore_element(cls, data):
         if not isinstance(data, dict):
             raise Exception('data must be dict')
 
