@@ -1,7 +1,9 @@
 import logging
 
-from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField, Max
+from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField
 from django.utils import timezone
+from transliterate import translit
+from transliterate.exceptions import LanguageDetectionError
 
 from isc_common import setAttr
 from isc_common.managers.common_manager import CommonManager, CommonQuerySet
@@ -97,6 +99,13 @@ class AuditModel(Model):
         from isc_common.common.functions import uncapitalize
         return uncapitalize(str)
 
+    @classmethod
+    def translit(cls, str):
+        try:
+            return cls.uncapitalize(translit(str, reversed=True).replace("'", '').replace(' ', '_').replace('.', '_'))
+        except LanguageDetectionError:
+            return cls.uncapitalize(str.replace("'", '').replace(' ', '_').replace('.', '_'))
+
     @classmethod
     def dbl_qutes_str(cls, str):
         from isc_common.common.functions import dbl_qutes_str
