@@ -1,7 +1,6 @@
 import logging
 
 from django.db.models import Model
-from transliterate import translit
 
 from isc_common import setAttr, delAttr
 from isc_common.bit import TurnBitOn, TurnBitOff
@@ -66,13 +65,13 @@ class BaseRefQuerySet(AuditQuerySet):
 
     def update(self, **kwargs):
         if kwargs.get('code') is None and kwargs.get('name') is not None:
-            setAttr(kwargs, 'code', AuditModel.uncapitalize(translit(kwargs.get('name'), reversed=True).replace("'", '').replace(' ', '_')))
+            setAttr(kwargs, 'code', AuditModel.translit(kwargs.get('name')))
         res = super().update(**kwargs)
         return res
 
     def create(self, **kwargs):
         if kwargs.get('code') is None and kwargs.get('name') is not None:
-            setAttr(kwargs, 'code', AuditModel.uncapitalize(translit(kwargs.get('name'), reversed=True).replace("'", '').replace(' ', '_')))
+            setAttr(kwargs, 'code', AuditModel.translit(kwargs.get('name')))
         res = super().create(**kwargs)
         return res
 
@@ -127,7 +126,7 @@ class BaseRef(AuditModel):
 
     def save(self, *args, **kwargs):
         if self.code is None:
-            self.code = AuditModel.uncapitalize(translit(self.name, reversed=True).replace("'", '').replace(' ', '_').replace('-', '_'))
+            self.code = AuditModel.translit(self.name)
         super().save(*args, **kwargs)
 
     class Meta:
@@ -204,7 +203,7 @@ class BaseRefHierarcy(Hierarcy):
 
     def save(self, *args, **kwargs):
         if self.code is None:
-            self.code = AuditModel.uncapitalize(translit(self.name, reversed=True).replace("'", '').replace(' ', '_'))
+            self.code = AuditModel.translit(self.name)
         super().save(*args, **kwargs)
 
     class Meta:
