@@ -12,7 +12,7 @@ def git_push(dest_path):
 def file_append(size, sized, full_path_source, max_size, files, dir_path_dest, full_path_dest):
     if sized + size > max_size:
         if sized > 0:
-            return False
+            return False, sized
     files.append((full_path_source, dir_path_dest, full_path_dest, size))
     sized += size
     print(f'file append ({round(sized / max_size * 1024, 2)} MB) : {full_path_dest}')
