@@ -7,7 +7,7 @@ from django.db import transaction
 from django.db.models import UUIDField, CharField, UniqueConstraint, Q
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr, Stack
+from isc_common import setAttr, delAttr
 from isc_common.auth.http.LoginRequets import LoginRequest
 from isc_common.auth.models.user import User
 from isc_common.fields.description_field import DescriptionField
@@ -28,13 +28,13 @@ class MessagesQuerySet(AuditQuerySet):
 
     def create(self, **kwargs):
         setAttr(kwargs, 'checksum', hashlib.md5(kwargs.get('message').encode()).hexdigest())
-        setAttr(kwargs, 'message', f'<pre>{kwargs.get("message")}</pre>')
+        # setAttr(kwargs, 'message', f'<pre>{kwargs.get("message")}</pre>')
         return super().create(**kwargs)
 
     def update(self, **kwargs):
         if kwargs.get('message') is not None:
             setAttr(kwargs, 'checksum', hashlib.md5(kwargs.get('message').encode()).hexdigest())
-            setAttr(kwargs, 'message', f'<pre>{kwargs.get("message")}</pre>')
+            # setAttr(kwargs, 'message', f'<pre>{kwargs.get("message")}</pre>')
         return super().update(**kwargs)
 
     def delete(self):
@@ -244,12 +244,13 @@ class MessagesManager(CommonTreeGridManager):
 
         old_to_whom_id = old_data.get('to_whom_id')
         to_whom_id = data.get('to_whom_id')
+        message_text = old_data.get('message').replace('<pre>', '').replace('</pre>', '')
 
         if old_to_whom_id != to_whom_id:
             setAttr(data_clone, 'user_id', request.user_id)
             setAttr(data_clone, 'parent_id', id)
             setAttr(data_clone, 'guid', uuid.uuid4())
-            setAttr(data, 'message', old_data.get('message'))
+            setAttr(data, 'message', message_text)
 
             with transaction.atomic():
                 res = super().create(**data_clone)
@@ -262,7 +263,7 @@ class MessagesManager(CommonTreeGridManager):
                                               bot=MessagesManager.get_tracker_bot(),
                                               message=f'<h3>Вам назначено новое дело:</h3>#{data_clone.get("guid")}'
                                                       f'<p/>Тема: {theme__full_name}'
-                                                      f'<p/>{MessagesManager.get_border(data_clone.get("message"), res.user)}'
+                                                      f'<p/>{MessagesManager.get_border(message_text, res.user)}'
                                                       f'<p/>Статус: "{Messages_state.objects.get(id=data_clone.get("state_id")).name}"'
                                                       f'<p/>Важность: "{Messages_importance.objects.get(id=data_clone.get("importance_id")).name}"'
                                                       f'<p/>Назначил: {res.user.get_short_name}'
@@ -271,7 +272,7 @@ class MessagesManager(CommonTreeGridManager):
             with transaction.atomic():
                 res = super().filter(id=id).update(
                     importance_id=data_clone.get('importance_id'),
-                    message=data_clone.get('message'),
+                    message=message_text,
                     state_id=data_clone.get('state_id'),
                     to_whom_id=data_clone.get('to_whom_id'),
                 )
@@ -295,7 +296,7 @@ class MessagesManager(CommonTreeGridManager):
                                                       bot=MessagesManager.get_tracker_bot(),
                                                       message=f'<h3>Изменение дела:</h3>#{data_clone.get("guid")}'
                                                               f'<p/>Тема: {data.get("theme__full_name")}'
-                                                              f'<p/>{MessagesManager.get_border(data.get("message"), user)}'
+                                                              f'<p/>{MessagesManager.get_border(message_text, user)}'
                                                               f'<p/>Cтатус: {Messages_state.objects.get(id=data_clone.get("state_id")).name if data_clone.get("state_id") is not None else None}'
                                                               f'<p/>Важность: {Messages_importance.objects.get(id=data_clone.get("importance_id")).name}'
                                                               f'<p/>Изменил: {user.get_short_name}')
@@ -339,7 +340,7 @@ class MessagesManager(CommonTreeGridManager):
                                                               f'<p/>Статус: {message.state.name}'
                                                               f'''<p/>Важность: {message.importance.name if message.importance else 'Не определена'}'''
                                                               f'<p/>Удалил: {request.user.get_short_name}'
-                                                          )
+                                                      )
                     res += qty
         return res
 
